# qfnn

The "qfnn" (or QuantumFlow Neural Network Library) 
is a library to support the implementation 
of [QuantumFlow](https://www.nature.com/articles/s41467-020-20729-5)
and its extensions, including [QF-Mixer](https://arxiv.org/pdf/2109.03806.pdf) and 
[QF-RobustNN](https://arxiv.org/pdf/2109.03430.pdf).


